<?php
/**
 * rhymes functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package rhymes
 */

add_action( 'after_setup_theme', 'rhymes_setup' ); 	
function rhymes_setup() {	
	global $content_width;

	if ( ! isset( $content_width ) ) $content_width = 690; //px
	
	load_theme_textdomain( 'rhymes', get_template_directory() . '/languages' );
	add_theme_support( 'title-tag' );
	add_image_size('rhyme_post_thumb',409,260);
	add_image_size('rhyme_single_post_thumb',750,450);
	add_image_size('rhymes_slide_thumb',1140,500);
	add_theme_support( 'post-thumbnails' ); //supports featured image
	add_theme_support( 'automatic-feed-links' );

	add_theme_support( 'custom-logo', array(
		'height'      => 60,
		'width'       => 200,
		'flex-width' => true,
	));
}

add_action('wp_enqueue_scripts', 'rhymes_style');

function google_fonts_url() {
    $font_url = ''; 
    if ( 'off' !== esc_html_x( 'on', 'Google font: on or off', 'rhymes' ) ) {
        $font_url = add_query_arg( 'family', urlencode('Open Sans:300,300i,400,400i,600,600i,700,700i,800,800i'), "//fonts.googleapis.com/css" );
    }
    return $font_url;
}



function rhymes_style(){
	wp_enqueue_style( 'rhymes-fonts-google-font', google_fonts_url(), array(), '1.0' );
	wp_enqueue_style('bootstrap',get_stylesheet_directory_uri(). '/css/bootstrap.min.css');
	wp_enqueue_style('font-awesome', get_stylesheet_directory_uri(). '/css/font-awesome.min.css');

	wp_enqueue_style('owl-carousel', get_stylesheet_directory_uri(). '/css/owl.carousel.min.css');

	wp_enqueue_style('rhymes-theme-style', get_stylesheet_directory_uri(). '/style.css');
	wp_enqueue_style('rhymes-theme-media', get_stylesheet_directory_uri(). '/css/media.css');
	
	//js 
	wp_enqueue_script('bootstrap', get_stylesheet_directory_uri(). '/css/bootstrap.min.js', array('jquery'));

	wp_enqueue_script('owl-carousel-js', get_stylesheet_directory_uri(). '/js/owl.carousel.min.js');

	wp_enqueue_script('masonry');
	
	if ( is_singular() ) wp_enqueue_script( "comment-reply" );
}
add_action('wp_footer','rhymes_footer_scripts');

function rhymes_footer_scripts(){
	wp_enqueue_script('rhymes-main-js', get_stylesheet_directory_uri(). '/js/script.js');
}
 
 //including customizer
require( get_template_directory().'/customizer.php');

add_action( 'wp_head', 'rhymes_color_css',999);
function rhymes_color_css(){ 
	$rhymes_options = get_theme_mod('rhymes_options');

	if($rhymes_options['site_color']!=''){
		$color= $rhymes_options['site_color'];
	} else{
		$color ='#12007c'; 
	} ?>

	<?php if($rhymes_options['site_bg_color'] !=''){
		$bgcolor= $rhymes_options['site_bg_color'];
	} else{
		$bgcolor ='#f9f9f9'; 
	} ?>
	<style>
	<?php if(isset($rhymes_options['breadcrump_bg']) && $rhymes_options['breadcrump_bg']!=''){ ?>
	.breadcum_bg {
	 	background-image: url(<?php echo esc_url($rhymes_options['breadcrump_bg']); ?>) !important;
	}
	<?php } ?>
	.container-bg {
		background: <?php echo esc_html( $bgcolor ); ?>;
	}
	.menu.navbar-default .navbar-nav > .open > a,
	.menu.navbar-default .navbar-nav > .open > a:focus,
	.menu.navbar-default .navbar-nav > .open > a:hover,
	.menu.navbar-default .navbar-nav  a:hover{
		color: <?php echo esc_html( $color ); ?> !important;
	}
	.menu.navbar-default .navbar-nav > .active > a,
	.menu.navbar-default .navbar-nav > .active > a:focus,
	.menu.navbar-default .navbar-nav > .active > a:hover{
		color: <?php echo esc_html( $color ); ?> !important;
	}
	.menu.navbar-default .navbar-nav > .open > a,
	.menu.navbar-default .navbar-nav > .open > a:focus,
	.menu.navbar-default .navbar-nav > .open > a:hover,
	.menu.navbar-default .navbar-nav  a:hover{
		color: <?php echo esc_html( $color ); ?> !important;
	}
	.rhymes-category-slider .category-content .btn-category {
		background: <?php echo esc_html( $color ); ?>;
	}
	.slider-text p  a{
		color: <?php echo esc_html( $color ); ?>;
	}
	.carousel-caption .btn {
		background-color: <?php echo esc_html( $color ); ?>;
		border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.swiper-pagination-bullet-active {
		background: <?php echo esc_html( $color ); ?>;
	}
	.w_blogs_post_desc {
		border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.w_breadcum {
		background: <?php echo esc_html( $color ); ?>;
	}
	.post-info li i{
		color:<?php echo esc_html( $color ); ?>;
	}
	.w_blogs_post_desc .btn {
		color: <?php echo esc_html( $color ); ?>;
		border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.w_blogs_post_desc .btn:hover {
		border: 1px solid <?php echo esc_html( $color ); ?>;
		background-color:<?php echo esc_html( $color ); ?>;
	}
	.widget-text .f_help li::before {
		color: <?php echo esc_html( $color ); ?>;
	}
	.widget-text .tags li a:hover{
		background-color:<?php echo esc_html( $color ); ?>;
	}
	.footer-copy a,.footer-copy a:hover{
		color:<?php echo esc_html( $color ); ?>;
	}
	.widget_contact .post-text:hover  p a{
		color: <?php echo esc_html( $color ); ?>;
	}
	.back-to-top i {
		background-color: <?php echo esc_html( $color ); ?>;
	}
	.w_sidebar .btn-search,
	.footer-widget .btn-search {
		background-color: <?php echo esc_html( $color ); ?>  !important;
	}
	.navbar-default .navbar-toggle {
		background-color: <?php echo esc_html( $color ); ?>  !important;
	}
	.w_sidebar li::before {
		color: <?php echo esc_html( $color ); ?> ;
	}
	.w_sidebar .tags li  a{
		border:1px solid <?php echo esc_html( $color ); ?> ;
	}
	.w_sidebar .tags li  a:hover{
		background-color:<?php echo esc_html( $color ); ?> ;
	}
	.footer-widget #footer-subscribe-btn {
		background: <?php echo esc_html( $color ); ?>;
		border: 2px solid <?php echo esc_html( $color ); ?>;
	}
	.w_subject .w_ser .icon {
		color: <?php echo esc_html( $color ); ?>;
	}
	.w_subject.subject-single h3 {
		color: <?php echo esc_html( $color ); ?>;
	}
	.w_blog_btn ul li a {
		border: 1px solid <?php echo esc_html( $color ); ?>;
		color: <?php echo esc_html( $color ); ?>;
	}
	.w_blog_btn ul li a:hover{
		border: 1px solid <?php echo esc_html( $color ); ?>;
	 	background-color: <?php echo esc_html( $color ); ?>;
	}
	.w_chapter .w_ser .tags  li a:hover {
		color: <?php echo esc_html( $color ); ?>;
	}
	.w_chapter .w_ser .cat  li a:hover {
		color: <?php echo esc_html( $color ); ?>;
	}
	.w_chapter .w_ser_text .button {
		background-color: <?php echo esc_html( $color ); ?>;
		border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.w_chapter .dropcaps .first {
		color: <?php echo esc_html( $color ); ?>;
	}
	.w_blog_pagination .next a,
	.w_blog_pagination .previous a {
		background-color: <?php echo esc_html( $color ); ?>;
		border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.pager li a:focus,
	.pager li a:hover {
		color:<?php echo esc_html( $color ); ?>;
	}
	.educa-error p.text-number {
		color: <?php echo esc_html( $color ); ?>;
		border-bottom: 2px dashed <?php echo esc_html( $color ); ?>;
	}
	.educa-error .error-text a.btn {
		background-color: <?php echo esc_html( $color ); ?>;
	}
	.w_post_desc h2 a:hover {
		color: <?php echo esc_html( $color ); ?>;
	}
	.w_blog_post  .post-cat a {
		color: <?php echo esc_html( $color ); ?>;
		border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.blog-post-pagination .next a,
	.blog-post-pagination .previous a {
		background-color: <?php echo esc_html( $color ); ?>;
		border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.blog-post-pagination .pager li a:focus,
	.blog-post-pagination .pager li a:hover {
		color:<?php echo esc_html( $color ); ?>;
	}
	.fixed-pagination .page .arrow {
		background-color: <?php echo esc_html( $color ); ?>;
	}
	.fixed-pagination .page .content {
		color:<?php echo esc_html( $color ); ?>;
		border:1px solid <?php echo esc_html( $color ); ?>;
	}
	.comment-respond .btn{
		background-color:<?php echo esc_html( $color ); ?>;
	}
	.blog-post-other h2 a {
		color: <?php echo esc_html( $color ); ?>;
	}
	.blog-post-chapter .w_post_desc p  a{
		color: <?php echo esc_html( $color ); ?>;
	}
	.w_toggle_type1 p, .w_toggle_type2 p {
		background-color: <?php echo esc_html( $color ); ?>;
	}
	.table  th {
		background-color: <?php echo esc_html( $color ); ?>;
	}
	.w_blog_post .img-thumbnail .overlay .icon{
		border:1px solid <?php echo esc_html( $color ); ?>;
		color:<?php echo esc_html( $color ); ?>;
	}
	.w_post_desc .tags  li a {
		color: <?php echo esc_html( $color ); ?>;
		border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.w_post_desc  .cat  li a {
		color: <?php echo esc_html( $color ); ?>;
		border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.w_home_chapter h1.heading  a{
	    background-color: <?php echo esc_html( $color ); ?>;
	}
	.w_home_chapter h1.heading{
		border-bottom: 2px solid <?php echo esc_html( $color ); ?>;
	}
	.back-to-top i {
		background-color: <?php echo esc_html( $color ); ?>;
	}
	#typed{
		color:<?php echo esc_html( $color ); ?>;
	}
	.footer-widget a:hover,
	#respond a,
	#respond a:hover {
		color:<?php echo esc_html( $color ); ?>;
	}
	.contact1 .btn {
	  	border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.contact1 .btn:hover {
	  	background-color: <?php echo esc_html( $color ); ?>;
	}
	.contact1-details .social li:hover {
		background-color:<?php echo esc_html( $color ); ?>;
	  	border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.contact1-details   .social:hover h3 {
	    color:<?php echo esc_html( $color ); ?>;
	}
	.edu-data a{
	   	color:<?php echo esc_html( $color ); ?>;
	}
	.edu-data .topic_link{
	  	color:#000;
	}
	.cat_post .w_post_desc {
	    border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.blog-pagination .pagination a:focus {
		background-color: <?php echo esc_html( $color ); ?>;
		border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.blog-pagination .pagination .current,
	.blog-pagination .pagination a:hover {
		background-color: <?php echo esc_html( $color ); ?>;
		border: 1px solid <?php echo esc_html( $color ); ?>;
	}
	.w_comment .comment-reply-link {
		background: <?php echo esc_html( $color ); ?>;
		border-color: <?php echo esc_html( $color ); ?>;
	}
	@media (max-width: 767px) {
		.menu .navbar-nav li a .fa.fa-angle-down {
			background: <?php echo esc_html( $color ); ?>;
		}
	}
</style>
<?php }


add_action( 'init', 'rhymes_menu' );
//Register area for custom menu
function rhymes_menu() {
	register_nav_menu( 'primary-menu', esc_html__( 'Primary Menu','rhymes' ) );
}
	
// for menu
function rhymes_page_menu_args( $args ) {
	if ( ! isset( $args['show_home'] ) )
		$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'rhymes_page_menu_args' );

 
function rhymes_fallback_page_menu( $args = array() ) {

	$defaults = array('sort_column' => 'menu_order, post_title', 'menu_class' => 'menu', 'echo' => true, 'link_before' => '', 'link_after' => '');
	$args = wp_parse_args( $args, $defaults );
	$args = apply_filters( 'wp_page_menu_args', $args );

	$menu = '';

	$list_args = $args;

	// Show Home in the menu
	if ( ! empty($args['show_home']) ) {
		if ( true === $args['show_home'] || '1' === $args['show_home'] || 1 === $args['show_home'] )
			$text = esc_html__('Home','rhymes');
		else
			$text = $args['show_home'];
		$class = '';
		if ( is_front_page() && !is_paged() )
			$class = 'class="current_page_item"';
		$menu .= '<li ' . $class . '><a href="' .   esc_url( home_url('/')) . '" title="' . esc_attr($text) . '">' . $args['link_before'] . $text . $args['link_after'] . '</a></li>';
		// If the front page is a page, add it to the exclude list
		if (get_option('show_on_front') == 'page') {
			if ( !empty( $list_args['exclude'] ) ) {
				$list_args['exclude'] .= ',';
			} else {
				$list_args['exclude'] = '';
			}
			$list_args['exclude'] .= get_option('page_on_front');
		}
	}

	$list_args['echo'] = false;
	$list_args['title_li'] = '';
	$list_args['walker'] = new rhymes_walker_page_menu;
	$menu .= str_replace( array( "\r", "\n", "\t" ), '', wp_list_pages($list_args) );

	if ( $menu )
		$menu = '<ul class="'. esc_attr($args['menu_class']) .'">' . $menu . '</ul>';

	$menu = '<div class="' . esc_attr($args['container_class']) . '">' . $menu . "</div>\n";
	$menu = apply_filters( 'wp_page_menu', $menu, $args );
	if ( $args['echo'] )
		echo $menu;
	else
		return $menu;
}
class rhymes_walker_page_menu extends Walker_Page{
	function start_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat("\t", $depth);
		$output .= "\n$indent<ul class='dropdown-menu'>\n";
	}
	function start_el( &$output, $page, $depth=0, $args = array(), $current_page = 0 ) {
		if ( $depth )
			$indent = str_repeat("\t", $depth);
		else
			$indent = '';

		extract($args, EXTR_SKIP);
		$css_class = array('page_item', 'page-item-'.$page->ID);
		if ( !empty($current_page) ) {
			$_current_page = get_post( $current_page );
			if ( in_array( $page->ID, $_current_page->ancestors ) )
				$css_class[] = 'current_page_ancestor';
			if ( $page->ID == $current_page )
				$css_class[] = 'current_page_item';
			elseif ( $_current_page && $page->ID == $_current_page->post_parent )
				$css_class[] = 'current_page_parent';
		} elseif ( $page->ID == get_option('page_for_posts') ) {
			$css_class[] = 'current_page_parent';
		}

		$css_class = implode( ' ', apply_filters( 'page_css_class', $css_class, $page, $depth, $args, $current_page ) );

		$output .= $indent . '<li class="' . $css_class . '"><a href="' . get_permalink($page->ID) . '">' . $link_before . apply_filters( 'the_title', $page->post_title, $page->ID ) . $link_after . '</a>';

		if ( !empty($show_date) ) {
			if ( 'modified' == $show_date )
				$time = $page->post_modified;
			else
				$time = $page->post_date;

			$output .= " " . mysql2date($date_format, $time);
		}
	}
}

/** nav-menu-walker.php */
class rhymes_nav_walker extends Walker_Nav_Menu {	
	function start_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat("\t", $depth);
		$output .= "\n$indent<ul class=\"dropdown-menu\">\n";
	}
	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		$class_names = $value = '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;
		$classes[] = 'menu-item-' . $item->ID;
		if(array_search("current-menu-item",$classes) || array_search("current-menu-ancestor",$classes)){
			$active_item= 1;
		}
		if ($args->has_children && $depth > 0) {
			$classes[] = 'dropdown dropdown-submenu';
		} else if($args->has_children && $depth === 0) {
			$classes[] = 'dropdown main-menu';
		}
		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );
		$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

		$id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );
		$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

		$output .= $indent . '<li' . $id . $value . $class_names .'>';

		$attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
		$attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
		$attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
		$attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';
		if(isset($active_item)){
		$attributes .= ' class="active-menu-item"';
		}
		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>';
		$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= ($args->has_children) ? '<i class="fa fa-angle-down"></i></a>' : '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}
	function display_element( $element, &$childrenl_elements, $max_depth, $depth=0, $args, &$output ) {

		if ( !$element )
			return;

		$id_field = $this->db_fields['id'];

		//display this element
		if ( is_array( $args[0] ) )
			$args[0]['has_children'] = ! empty( $childrenl_elements[$element->$id_field] );
		else if ( is_object( $args[0] ) ) 
			$args[0]->has_children = ! empty( $childrenl_elements[$element->$id_field] ); 
		$cb_args = array_merge( array(&$output, $element, $depth), $args);
		call_user_func_array(array($this, 'start_el'), $cb_args);

		$id = $element->$id_field;

		// descend only when the depth is right and there are childrens for this element
		if ( ($max_depth == 0 || $max_depth > $depth+1 ) && isset( $childrenl_elements[$id]) ) {

			foreach( $childrenl_elements[ $id ] as $child ){

				if ( !isset($newlevel) ) {
					$newlevel = true;
					//start the child delimiter
					$cb_args = array_merge( array(&$output, $depth), $args);
					call_user_func_array(array($this, 'start_lvl'), $cb_args);
				}
				$this->display_element( $child, $childrenl_elements, $max_depth, $depth + 1, $args, $output );
			}
			unset( $childrenl_elements[ $id ] );
		}

		if ( isset($newlevel) && $newlevel ){
			//end the child delimiter
			$cb_args = array_merge( array(&$output, $depth), $args);
			call_user_func_array(array($this, 'end_lvl'), $cb_args);
		}

		//end this element
		$cb_args = array_merge( array(&$output, $element, $depth), $args);
		call_user_func_array(array($this, 'end_el'), $cb_args);
	}
}

function rhymes_nav_menu_css_class( $classes ) {
	if ( in_array('current-menu-item', $classes ) OR in_array( 'current-menu-ancestor', $classes ) ){
		$classes[]	=	'active';
	}
	return $classes;
}
add_filter( 'nav_menu_css_class', 'rhymes_nav_menu_css_class' );

function rhymes_numeric_posts_nav() {
	the_posts_pagination( array( 'mid_size' => 2 ) );
}

function rhymes_navigation_posts() { ?>
<div class="row blog-post-pagination">
	<ul class="pager">
		<li class="next">
			<?php previous_post_link('%link', '%title', TRUE, ' '); ?>
		</li>
		<li class="previous">
			<?php next_post_link( '%link', '%title', TRUE, ' '); ?>
		</li>
	</ul>
</div>	
<?php }
	
// comment function
if ( ! function_exists( 'rhymes_theme_comment' ) ) :
function rhymes_theme_comment($comment, $args, $depth){
	//get theme data
	global $comment_data;
	//translations
	$leave_reply = $comment_data['translation_reply_to_coment'] ? $comment_data['translation_reply_to_coment'] : 
	esc_html__('Reply','rhymes'); ?>
    <div class="col-xs-12 comment-detail">
    	<?php if(get_avatar($comment,$size = '100')) { ?>
		<div class="col-xs-2 comments-pics">
			<?php echo get_avatar($comment,$size = '100'); ?>
		</div>
		<?php } ?>
		<?php 
			if(get_avatar($comment,$size = '100')) {
				$commentClass = 'col-xs-10';
			} else {
				$commentClass = 'pdl-15 col-xs-12';
			}
		?>
		<div class="<?php echo esc_attr($commentClass); ?> comments-text">
				<span>
				<?php if ( ('d M  y') == get_option( 'date_format' ) ) : ?>				
				<?php comment_date('F j, Y');?>
				<?php else : ?>
				<?php comment_date(); ?><?php esc_html_e('at','rhymes');?>&nbsp;<?php comment_time('g:i a'); ?>
				<?php endif; ?></span>
				<?php comment_reply_link(array_merge( $args, array('reply_text' => $leave_reply,'depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
			<h3><?php comment_author();?></h3>
			<p><?php comment_text() ; ?></p>
			<?php if ( $comment->comment_approved == '0' ) : ?>
				<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'rhymes' ); ?></em>
				<?php endif; ?>
		</div>
	</div>
<?php }
endif;

// widgets function
function rhymes_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__('Sidebar Widget Area','rhymes'),
		'id'            => 'theme_sidebar_widget',
		'before_widget' => '<div class="row w_sidebar">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__('Sidebar Widget Area For Page','rhymes'),
		'id'            => 'theme_sidebar_page',
		'before_widget' => '<div class="row w_sidebar">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__('Footer Widget Area','rhymes'),
		'id'            => 'theme_footer_widget',
		'before_widget' => '<div class="col-md-4 col-sm-6"><div class="footer-widget">',
		'after_widget'  => '</div></div></div>',
		'before_title'  => '<div class="widget-heading"><h2 class="widget-title">',
		'after_title'   => '</h2></div><div class="widget-text">',
	) );
}
add_action( 'widgets_init', 'rhymes_widgets_init' );


require( get_template_directory() . '/inc/libs/tgm-plugin-activation/tgm-admin-config.php' );

require( get_template_directory() . '/inc/breadcrumbs.php' );
?>