<?php 
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package rhymes
 */
get_header(); ?>

<div class="container-fluid w_blog blog-home container-bg">
	<?php 
		$rhymes_options = get_theme_mod('rhymes_options');
		if ( 'posts' == get_option( 'show_on_front' ) && !is_paged() ) {
			if(!isset($rhymes_options['show_slider'])){
				$show_slider = 'on';
			} else{
				$show_slider = $rhymes_options['show_slider'];
			}
			if(!isset($rhymes_options['category_slider'])){
				$category_slider='';
			} else{
				$category_slider=$rhymes_options['category_slider'];
			}
			if($show_slider=='on') { ?>
				<!-- Slider Start  -->
				<div class="rhyme-slider">
					<?php $rhymes_args =	array(
						'post_type'        => 'post',
						'category_name'    => $category_slider,
						'post_per_page'    => 5,
						'post_status'      => 'publish',
						'suppress_filters' => true
					); 
					$rhymes_slider= new WP_Query($rhymes_args); 
					if($rhymes_slider->have_posts()):?>
					<div class="rhymes-category-slider owl-carousel">
					<?php 
					while($rhymes_slider->have_posts()):
					$rhymes_slider->the_post(); 
					if ( has_post_thumbnail() ) { ?>
						<div class="item">
							<figure class="category-thumbnail" style="background-image: url(<?php echo esc_attr(get_the_post_thumbnail_url(get_the_ID(),'full')); ?>);">
								<div class="container">
								<div class="category-content">
									<div class="content-bg">						
										<div class="post-footer-meta">					
											<span><i class="fa fa-user"></i><a href="<?php echo esc_url(get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ) ); ?>"><?php the_author(); ?></a></span>
											<span><i class="fa fa-calendar"></i><?php echo human_time_diff( get_the_time('U'), current_time('timestamp') ) . ' ago'; ?></span>
											<span><i class="fa fa-commenting"></i><?php echo comments_number( '0', '1', '%' ); ?></span>
										</div><!--  /.post-meta -->
										<h2 class="category-title"><?php the_title(); ?></h2>
										<p class="category-description"><?php echo esc_html(wp_trim_words(get_the_excerpt(), 35)); ?></p>
										<a href="<?php the_permalink(); ?>" class="btn btn-category" > <?php esc_html_e('Read More','rhymes'); ?></a>
									</div><!--  /.content-bg -->
								</div>
								</div><!--  /.container -->
							</figure>
						</div><!--  /.item -->
					<?php } endwhile; ?>
					</div>
					<?php endif; wp_reset_postdata(); ?>
				</div>
				<!-- Slider End -->
			<?php }
		}
	?>
	<div class="container mrt-60">
		<div class="row">
			<div class="col-md-8 col-sm-8 right-side blog_gallery">
				<?php  if ( have_posts()) { ?>
				<div class="row masonry">
					<?php while ( have_posts() ): the_post(); ?>
						<div class="col-md-6 w_blog_post">
							<div class="w_post_desc">
								<div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
									<div class="post-head-wrap">
										<?php if(has_post_thumbnail()): ?>
											<div class="post-thumbs">
												<a href="<?php the_permalink(); ?>">
													<div class="img-thumbnail">
														<?php $data= array('class' =>'img-responsive post_image'); 
														the_post_thumbnail('rhyme_post_thumb', $data); ?>
													</div>
												</a>
											</div>
										<?php endif; ?>	
									</div><!--  /.post-head -->
									<div class="post-content-wrap">
										<h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
										<div class="post-content">
											<?php the_excerpt(); ?>
										</div>

										<div class="post-footer-meta">					
											<span><i class="fa fa-user"></i><a href="<?php echo esc_url(get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ) ); ?>"><?php the_author(); ?></a></span>
											<span><i class="fa fa-calendar"></i><?php echo human_time_diff( get_the_time('U'), current_time('timestamp') ) . ' ago'; ?></span>
											<span><i class="fa fa-commenting"></i><?php echo comments_number( '0', '1', '%' ); ?></span>
											<?php if( get_the_post_thumbnail() == "" && get_the_title() == ""): ?>
											<span class="entry-date no-title"><a href="<?php the_permalink(); ?>"><i class="fa fa-external-link-square"></i></a></span>
											<?php endif; ?>
										</div><!--  /.post-meta -->
									</div><!--  /.post-content-wrap -->
								</div>
							</div><!--  /.w_post_desc -->
						</div>
					<?php endwhile; ?>
				</div><!--  /.row -->

				<?php } else { ?>
					<div class="space educa-not-found clearfix">
						<div class="error-no">
							<div class="not-found-icon">
								<i class="fa fa-exclamation-triangle icon"></i>
							</div>
							<p class="text"><?php esc_html_e('Page Not Found','rhymes'); ?></p>
						</div>	
						<div class="error-text">
							<p><?php esc_html_e('The Page you requested is not be found. This could be spelling error in the url.','rhymes'); ?></p>
							<a class="btn" href="<?php echo esc_url(home_url( '/' )); ?>"><?php esc_html_e('Go back to homepage','rhymes'); ?></a>
						</div>
					</div>	
				<?php }   ?>
				
				<div class="row">
					<div class="col-md-12">
						<div class="center blog-pagination ">
							<?php rhymes_numeric_posts_nav(); ?>
						</div>
					</div><!--  /.col-md-12 -->
				</div><!--  /.row -->
			</div><!--  /.col-md-8 -->
			<div class="col-md-4">
				<div class="blog-sidebar">
					<?php get_sidebar(); ?>
				</div><!--  /.blog-sidebar -->
			</div><!--  /.col-md-4 -->
		</div><!--  /.row -->
	</div>	
</div>
<?php get_footer(); ?>